Training
========
.. automodapi:: pykeen.training
    :no-heading:
    :headings: --
    :skip: TrainingCallback,callback_resolver
    :include-all-objects:

Callbacks
---------
.. automodapi:: pykeen.training.callbacks
    :no-heading:
    :headings: ~~
    :include-all-objects:

Learning Rate Schedulers
------------------------
.. automodapi:: pykeen.lr_schedulers
    :no-heading:
    :headings: ~~
    :include-all-objects:
